JSONEngineUrl

Struct JSONEngineUrl 

pub struct JSONEngineUrl {
    pub base: Option<String>,
    pub method: Option<JSONEngineMethod>,
    pub params: Option<Vec<SearchUrlParam>>,
    pub search_term_param_name: Option<String>,
    pub display_name_map: Option<HashMap<String, String>>,
    pub is_new_until: Option<String>,
    pub exclude_partner_code_from_telemetry: bool,
    pub accepted_content_types: Option<Vec<String>>,
}
Defines an individual search engine URL. This is defined separately to types::SearchEngineUrl as various fields may be optional in the supplied configuration.

Fields

base: Option<String>

The PrePath and FilePath of the URL. May include variables for engines which have a variable FilePath, e.g. {searchTerms} for when a search term is within the path of the url.

method: Option<JSONEngineMethod>

The HTTP method to use to send the request (GET or POST). If the engine definition has not specified the method, it defaults to GET.

params: Option<Vec<SearchUrlParam>>

The parameters for this URL.

search_term_param_name: Option<String>

The name of the query parameter for the search term. Automatically appended to the end of the query. This may be skipped if {searchTerms} is included in the base.

display_name_map: Option<HashMap<String, String>>

A map from locale codes to display names of the URL. This is useful if the URL corresponds to a brand name distinct from the engine’s brand name. Since brand names can be localized, this is a map rather than a URL. The client will fall back to the special locale code “default” when its locale is not present in the map.

is_new_until: Option<String>

Indicates the date until which the URL is considered new (format: YYYY-MM-DD).

exclude_partner_code_from_telemetry: bool

Whether the engine’s partner code should be excluded from telemetry when this URL is visited.

accepted_content_types: Option<Vec<String>>

If this URL performs searches only for certain MIME types, they should be listed here. If this value is None, then it’s assumed the content type is irrelevant. This field is intended to be used for URLs like visual search, which might support certain image types and not others. Consumers can use it to determine whether search UI corresponding to the URL should be shown to the user in a given context.